@@ -41,8 +41,8 @@ class QAStage(Stage):
         super(QAStage, self).__init__(**data)
         self.raw_data = data
         self.stage_type = data.get("stage_type")
-        self.corpus = {}
-        corpus = data.get(self.__CORPUS__)
+        # self.corpus = {}
+        self.corpus = data.get(self.__CORPUS__)
         # for k, v in corpus.items():
         #     self.corpus[k.replace(" ", "")] = v.replace(" ", "")
 
