@@ -61,8 +61,7 @@ class Stage:
     @classmethod
     def save_user_text(cls, data, stage_id, label):
         user_text = cls.get_user_text(data)
-        data = cls.set_default_var(data,__KEEP_DEFAULT_VAR__,"__USER_TEXT__",user_text)
-        data = cls.set_var(data, stage_id, label, user_text)
+        data = cls.set_var(data, __KEEP_DEFAULT_VAR__, __USER_TEXT__, user_text)
         return cls.set_var(data, stage_id, label, user_text)
 
     @staticmethod
